@@ -1,13 +1,24 @@
 #include "utils.h"
-#include <QDateTime>
 #include <QFileInfo>
 #include <QFile>
+#include <QRegExp>
 #ifndef QML_USER_INTERFACE
 #include <QPainter>
 #include <QRect>
 #include <QImage>
 #endif
 
+const QRegExp YOUTUBE_URL_RE("(http(s|)://(www.|m.|)youtube.com/(v/|.+)(v=|list=|)|http://youtu.be/)", Qt::CaseInsensitive);
+const QRegExp DAILYMOTION_URL_RE("(http(s|)://(www.|)dailymotion.com/|http://dai.ly/)\\w+", Qt::CaseInsensitive);
+const QRegExp VIMEO_URL_RE("http(s|)://vimeo.com/\\w+", Qt::CaseInsensitive);
+
+Utils::Utils(QObject *parent) :
+    QObject(parent)
+{
+}
+
+Utils::~Utils() {}
+
 QString Utils::durationFromSecs(int secs) {
     QTime time(0, 0);
     QString format = secs >= 3600 ? "hh:mm:ss" : "mm:ss";
@@ -67,6 +78,70 @@ QString Utils::dateFromMSecs(qint64 msecs, bool showTime) {
     return date;
 }
 
+QString Utils::toRichText(QString s) {
+    QRegExp re("((http(s|)://|[^\\s<\"']+@)[^\\s<\"']+)");
+    int pos = 0;
+
+    while ((pos = re.indexIn(s, pos)) != -1) {
+        QString link = re.cap(1);
+        s.replace(pos, link.size(), QString("<a href='%1'>%2</a>").arg(link.contains('@') ? "mailto:" + link : link).arg(link));
+        pos += re.matchedLength() * 2 + 15;        
+    }
+
+    return s.replace("\n", "<br>");
+}
+
+QVariantMap Utils::parseIdFromUrl(const QString &url) {
+    QVariantMap result;
+
+    if (YOUTUBE_URL_RE.indexIn(url) == 0) {
+        result.insert("service", Services::YouTube);
+        result.insert("id", url.section(QRegExp("v=|list=|/"), -1).section(QRegExp("&|\\?"), 0, 0));
+
+        if ((url.contains("youtu.be")) || (url.contains("v=") || (url.contains("/v/")))) {
+            result.insert("type", Queries::Videos);
+        }
+        else if (url.contains("list=")) {
+            result.insert("type", Queries::Playlists);
+        }
+        else {
+            result.insert("type", Queries::Users);
+        }
+    }
+    else if (DAILYMOTION_URL_RE.indexIn(url) == 0) {
+        result.insert("service", Services::Dailymotion);
+        result.insert("id", url.section('/', -1).section('_', 0, 0));
+
+        if ((url.contains("dai.ly") || (url.contains("/video/")))) {
+            result.insert("type", Queries::Videos);
+        }
+        else if (url.contains("/playlist/")) {
+            result.insert("type", Queries::Playlists);
+        }
+        else {
+            result.insert("type", Queries::Users);
+        }
+    }
+    else if (VIMEO_URL_RE.indexIn(url) == 0) {
+        QString id = url.section('/', -1);
+
+        result.insert("service", Services::Vimeo);
+        result.insert("id", id);
+
+        if (url.contains("/album/")) {
+            result.insert("type", Queries::Playlists);
+        }
+        else if (id.contains(QRegExp("\\D+"))) {
+            result.insert("type", Queries::Users);
+        }
+        else {
+            result.insert("type", Queries::Videos);
+        }
+    }
+
+    return result;
+}
+
 QString Utils::base64Id(const QString &artist, const QString &title) {
     return QString(artist.toUtf8().toBase64() + "-" + title.toUtf8().toBase64());
 }
@@ -81,19 +156,6 @@ QString Utils::localDateTimeFromString(const QString &dateTimeString, Qt::DateFo
     return dt.toLocalTime().toString("dd/MM/yyyy | HH:mm");
 }
 
-QString Utils::serviceString(Services::VideoService service) {
-    switch (service) {
-    case Services::YouTube:
-        return QString("YouTube");
-    case Services::Dailymotion:
-        return QString("Dailymotion");
-    case Services::Vimeo:
-        return QString("Vimeo");
-    default:
-        return QString();
-    }
-}
-
 QString Utils::unescape(const QString &s) {
     int unescapes = 0;
     QByteArray us = s.toUtf8();
@@ -116,10 +178,6 @@ void Utils::log(const QString &filePath, const QByteArray &message) {
     lf.close();
 }
 
-QString Utils::versionNumberString() {
-    return QString("1.9.5");
-}
-
 #ifndef QML_USER_INTERFACE
 void Utils::drawBorderImage(QPainter *painter, const QRect &rect, const QImage &image, int top, int right, int left, int bottom) {
     QRect imageRect = image.rect();
