@@ -1,5 +1,5 @@
 #include "vimeo.h"
-#include "../../cutetubeapp/src/base/utils.h"
+#include "../../cutetubeapp/src/base/definitions.h"
 #include "../../cutetubeapp/src/base/oauth.h"
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
@@ -40,7 +40,7 @@ QNetworkReply* Vimeo::createReply(QString feed, int offset) {
     qDebug() << url;
 
     QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(VERSION_NUMBER).toUtf8());
     request.setRawHeader("Authorization", this->getOAuthHeader("GET", url, QMap<QString, QString>()));
 
     return this->networkAccessManager()->get(request);
